@@ -6,13 +6,10 @@ import typer
 from bigeye_sdk.client.enum import Method
 
 from bigeye_cli.enums import OPS_METRICS
-from bigeye_sdk.client.datawatch_client import BasicAuthDatawatchClient
 from bigeye_sdk.model.protobuf_enum_facade import MetricStatus, SimpleMetricCategory
-from bigeye_cli import HOME_DIR
-from bigeye_aws.functions.aws import get_secret
+from bigeye_sdk.functions.aws import get_secret
 from bigeye_sdk.generated.com.torodata.models.generated import MetricInfoList, WarehouseType, CreateSourceRequest, \
-    TimeIntervalType, PredefinedMetricName, MetricCreationState, MetricConfiguration, TimeInterval, \
-    BatchMetricConfigRequest, ForecastModelType
+    TimeIntervalType, PredefinedMetricName, MetricCreationState, MetricConfiguration, ForecastModelType
 from bigeye_sdk.log import get_logger
 from bigeye_cli.functions import write_metric_info, cli_client_factory, write_table_info, write_debug_queries
 from bigeye_sdk.functions.metric_functions import has_auto_threshold
@@ -154,11 +151,11 @@ def delete_metrics(
             , "--table_id"
             , "-tid"
             , help="Table IDs.  E.g. -tid 123 -tid 124"),
-        metric_names: Optional[List[str]] = typer.Option(
+        metric_type: Optional[List[str]] = typer.Option(
             None
-            , "--metric_name"
+            , "--metric_type"
             , "-m"
-            , help=f"Predefined Metric Names to filter by."
+            , help=f"Delete by name of the metric type."
                    f"{', '.join([i.name for i in PredefinedMetricName])}"),
 ):
     """Delete metrics in a warehouse id, by schema names, or by table_ids.  Also, can filter by multipe
@@ -167,15 +164,17 @@ def delete_metrics(
 
     mil: MetricInfoList = client.get_metric_info_batch_post(warehouse_ids=[warehouse_id],
                                                             table_ids=table_ids)
+
     if schema_names:
         mil.metrics = [m for m in mil.metrics if m.metric_metadata.schema_name in schema_names]
 
-    if metric_names:
+    if metric_type:
         mil.metrics = [m for m in mil.metrics
-                       if SimpleMetricCategory.get_metric_name(m.metric_configuration.metric_type) in metric_names]
+                       if SimpleMetricCategory.get_metric_name(m.metric_configuration.metric_type) in metric_type]
 
-    for m in mil.metrics:
-        client.delete_metric(metric_id=m.metric_configuration.id)
+    metrics = [m.metric_configuration for m in mil.metrics]
+
+    client.delete_metrics(metrics=metrics)
 
 
 @app.command()
